@@ -1795,6 +1795,87 @@ if(raa_current_db == NULL) return NULL;
 }
 
 
+char *raa_readaut(raa_db_access *raa_current_db, int num, int *plref)
+{
+  Reponse *rep;
+  char *p, *reponse;
+  int code;
+
+if(raa_current_db == NULL) return NULL;
+  rep=initreponse();
+  sock_printf(raa_current_db,"readaut&num=%u\n", num);
+  reponse = read_sock(raa_current_db);
+  if(reponse == NULL) return NULL;
+  parse(reponse, rep);
+  p = val(rep,"code");
+  if(p == NULL) return NULL;
+  code = atoi(p);
+  free(p);
+  if(code == 0) {
+  	if(plref != NULL) {
+  		p = val(rep, "plref");
+  		*plref = atoi_u(p);
+  		free(p);
+  		}
+  	p = val(rep, "name");
+  	strcpy(raa_current_db->author, p);
+  	free(p);
+  	p = raa_current_db->author;
+  	}
+  else p = NULL;
+  clear_reponse(rep);
+  return p;  
+}
+
+
+char *raa_readbib(raa_db_access  *raa_current_db, int num, int *plsub, int *plaut, int *pj, int *py)
+{
+  Reponse *rep;
+  char *p, *reponse;
+  int code;
+  
+  if (raa_current_db == NULL) return NULL;
+  rep=initreponse();
+  sock_printf(raa_current_db,"readbib&num=%u\n", num);
+  reponse = read_sock(raa_current_db);
+  if (reponse == NULL) return NULL;
+  parse(reponse, rep);
+  p = val(rep,"code");
+  if(p == NULL) return NULL;
+  code = atoi(p);
+  free(p);
+  if (code == 0) {
+    if (plsub != NULL) {
+      p = val(rep, "plsub");
+      *plsub = atoi_u(p);
+      free(p);
+      }
+    if (plaut != NULL) {
+      p = val(rep, "plaut");
+      *plaut = atoi_u(p);
+      free(p);
+    }
+    if (pj != NULL) {
+      p = val(rep, "j");
+      *pj = atoi_u(p);
+      free(p);
+    }
+    if (py != NULL) {
+      p = val(rep, "y");
+      *py = atoi_u(p);
+      free(p);
+    }
+    p = val(rep, "name");
+    strcpy(raa_current_db->biblio, p);
+    free(p);
+    p = raa_current_db->biblio;
+  }
+  else p = NULL;
+  clear_reponse(rep);
+  return p;
+}
+
+
 int raa_readext(raa_db_access *raa_current_db, int num, int *mere, int *deb, int *fin)
 {
   Reponse *rep;
