@@ -438,7 +438,7 @@ void Fl_PICT_Graphics_Driver::draw(const char* str, int n, float fx, float fy) {
 
 #endif // USE_PICT
 
-Fl_Copy_Surface::Fl_Copy_Surface(bool pict, int w, int h) : Fl_Surface_Device(NULL)
+Copy_Surface::Copy_Surface(bool pict, int w, int h) : Fl_Surface_Device(NULL)
 {
 #ifdef USE_PICT
   use_pict = pict;
@@ -466,7 +466,7 @@ Fl_Copy_Surface::Fl_Copy_Surface(bool pict, int w, int h) : Fl_Surface_Device(NU
     }
 }
 
-Fl_Copy_Surface::~Fl_Copy_Surface()
+Copy_Surface::~Copy_Surface()
 {
   if (use_pict) {
 #ifdef USE_PICT
@@ -482,7 +482,7 @@ Fl_Copy_Surface::~Fl_Copy_Surface()
   delete driver();
 }
 
-size_t Fl_Copy_Surface::MyPutBytes (void* info, const void* buffer, size_t count)
+size_t Copy_Surface::MyPutBytes (void* info, const void* buffer, size_t count)
 {
   CFDataAppendBytes ((CFMutableDataRef) info, (const UInt8 *)buffer, count);
   return count;
@@ -490,7 +490,7 @@ size_t Fl_Copy_Surface::MyPutBytes (void* info, const void* buffer, size_t count
 
 
 #ifdef USE_PICT
-QDPictRef Fl_Copy_Surface::MyPictToQDPict()
+QDPictRef Copy_Surface::MyPictToQDPict()
 {
   CFIndex pictlen;
   CGDataProviderRef provider;
@@ -509,7 +509,7 @@ QDPictRef Fl_Copy_Surface::MyPictToQDPict()
 }
 
 
-void Fl_Copy_Surface::MyCopyPictToClipboard()
+void Copy_Surface::MyCopyPictToClipboard()
 {
   CFDataRef  data = NULL;
   PasteboardRef clipboard = NULL;
@@ -550,7 +550,7 @@ void Fl_Copy_Surface::MyCopyPictToClipboard()
 }
 #endif // USE_PICT
 
-void Fl_Copy_Surface::init_PDF_context(int w, int h)
+void Copy_Surface::init_PDF_context(int w, int h)
 {
   CGRect bounds = CGRectMake(0, 0, w, h );	
   pdfdata = CFDataCreateMutable(NULL, 0);
@@ -567,7 +567,7 @@ void Fl_Copy_Surface::init_PDF_context(int w, int h)
 }
 
 //next 2 functions copy quartz data to clipboard both as pdf and as tiff bitmap
-void Fl_Copy_Surface::prepare_copy_pdf_and_pict(int w, int h)
+void Copy_Surface::prepare_copy_pdf_and_pict(int w, int h)
 {
   init_PDF_context(w, h);
   if (gc == NULL) return;
@@ -577,7 +577,7 @@ void Fl_Copy_Surface::prepare_copy_pdf_and_pict(int w, int h)
   CGContextScaleCTM(gc, 1.0f, -1.0f);
 }
 
-void Fl_Copy_Surface::complete_copy_pdf_and_pict()
+void Copy_Surface::complete_copy_pdf_and_pict()
 {
   int w, h;
   CGContextEndPage (gc);
