@@ -131,7 +131,7 @@ typedef Fl_PDF_File_Device Fl_PDF_or_PS_File_Device;
 
 #if (defined(__APPLE__) || defined(WIN32))
 
-class Fl_Copy_Surface : public Fl_Surface_Device {
+class Copy_Surface : public Fl_Surface_Device {
 #ifdef __APPLE__
   bool use_pict;
   CFMutableDataRef pdfdata;
@@ -151,11 +151,11 @@ class Fl_Copy_Surface : public Fl_Surface_Device {
 #endif
 public:
 #ifdef __APPLE__
-  Fl_Copy_Surface(bool use_pict, int w, int h);
+  Copy_Surface(bool use_pict, int w, int h);
 #else
-  Fl_Copy_Surface(int w, int h);
+  Copy_Surface(int w, int h);
 #endif
-  ~Fl_Copy_Surface();
+  ~Copy_Surface();
 };
 #endif
 
