@@ -504,7 +504,7 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 		free_after_view_to_allseq(phyml_seqs);
 		return NULL;
 		}
-	phyml_mat->method = !use_bionj; //1:NJ 0:BioNJ
+	phyml_mat->method = use_bionj; //0:NJ 1:BioNJ
 	phyml_mat->tree = Make_Tree_From_Scratch(phyml_seqs->n_otu, phyml_seqs);
 	Bionj(phyml_mat);
 	sprintf(tree_label, "%s %d sites %s", use_bionj ? "BioNJ" : "NJ",
@@ -525,7 +525,7 @@ char *run_distance_method(SEA_VIEW *view, int distkind, int remove_all_gaps, int
 					if (!tree_build_interrupted) total = 0;
 					break;
 					}
-				phyml_mat->method = ! use_bionj; //1:NJ 0:BioNJ
+				phyml_mat->method = use_bionj; // 0:NJ 1:BioNJ
 				phyml_mat->tree = Make_Tree_From_Scratch(phyml_seqs->n_otu, phyml_seqs);
 				Bionj(phyml_mat);
 				char *one_replicate_tree = Write_Tree(phyml_mat->tree);
