@@ -15,7 +15,7 @@ char **getutf8args(int *pargc);
 int mysystem(const char *cmd);
 
 
-Fl_Copy_Surface::Fl_Copy_Surface(int w, int h) : Fl_Surface_Device(new Fl_GDI_Graphics_Driver())
+Copy_Surface::Copy_Surface(int w, int h) : Fl_Surface_Device(new Fl_GDI_Graphics_Driver())
 {
   HDC oldflgc = fl_gc;
   //int factor = 32; // empirically set
@@ -40,7 +40,7 @@ Fl_Copy_Surface::Fl_Copy_Surface(int w, int h) : Fl_Surface_Device(new Fl_GDI_Gr
     }
 }
 
-Fl_Copy_Surface::~Fl_Copy_Surface()
+Copy_Surface::~Copy_Surface()
 {
   if(oldflgc == fl_gc) oldflgc = NULL;
   HENHMETAFILE hmf = CloseEnhMetaFile (fl_gc);
